<template>
  <el-dialog
      v-model="dialogVisible"
      title="选择区域"
      width="900px"
      draggable
      :fullscreen="full"
  >
    <el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
    <el-row>
      <el-col :span="18">
        <el-form :inline="true" ref="ruleFormRef" :model="ruleForm" status-icon>
          <el-form-item>
            <el-input size="default" v-model="ruleForm.checkPass" placeholder="风险区域名称" style="max-width: 215px;" />
          </el-form-item>
          <el-form-item>
            <el-button size="default" type="primary" @click="submitForm(ruleFormRef)" style="margin-left: 12px;">查询</el-button>
            <el-button size="default" @click="resetForm(ruleFormRef)">重置</el-button>
          </el-form-item>
          <el-button size="default" :icon="Delete" style="margin-left: 12px;">清除选择</el-button>
        </el-form>
        <el-table :data="tableData" style="width: 100%;margin-top:20px;">
          <el-table-column align="center" width="55">
          <template #default="scope">
            <el-radio-group v-model="radio1" @change="radio">
              <el-radio :label="scope.row.name" size="large">{{null}}</el-radio>
            </el-radio-group>
          </template>
          </el-table-column>
          <el-table-column align="center" prop="name" label="风险区域名称"/>
        </el-table>
        <div class="pages">
          <el-pagination
              v-model:currentPage="pageIndex"
              v-model:page-size="pageSize"
              :page-sizes="[10, 20, 30]"
              :pager-count="5"
              :small="small"
              :disabled="disabled"
              :background="background"
              layout="total, sizes, prev, pager, next, jumper"
              :total="40"
              @size-change="handleSizeChange"
              @current-change="handleCurrentChange"
          />
        </div>
      </el-col>
      <el-col :span="6" style="padding-left: 15px;">
        <el-tag
            v-for="tag in dynamicTags"
            :key="tag"
            class="mx-1"
            style="margin: 5px"
            closable
            :disable-transitions="false"
            @close="handleClose(tag)"
        >
          {{ tag }}
        </el-tag>
      </el-col>
    </el-row>
    <template #footer>
			<span class="dialog-footer">
				<el-button @click="dialogVisible = false" size="default">关闭</el-button>
				<el-button type="primary" @click="dialogVisible = false" size="default">确定</el-button>
			</span>
    </template>
  </el-dialog>
</template>
<script lang="ts">
import {
  defineComponent,
  reactive,
  ref
} from 'vue';
import {
  Delete,
  FullScreen
} from '@element-plus/icons-vue';
export default defineComponent({
  setup() {
    const dialogVisible = ref<boolean>(false);
    const openDailog = () => {
      dialogVisible.value = true;
    };
    // 搜索条件
    const ruleForm = reactive({
      checkPass: '',
    });
    // 表格
    const tableData = [
      {
        name: '1#LNG储罐单元',
      },
      {
        name: 'LNG装车区',
      },
      {
        name: '丙烷储罐区',
      },
      {
        name: '4#LNG储罐单元',
      },
    ];
    // 右方点击添加后显示标签
    const dynamicTags = ref(['LNG装车区']);
    const handleClose = (tag: string) => {
      dynamicTags.value.splice(dynamicTags.value.indexOf(tag), 1);
      radio1.value=""
    };
    const radio1=ref('1#LNG储罐单元')
    const radio=(event:any)=>{
      dynamicTags.value[0]=event
    }

    // 分页
    const pageIndex = ref(4);
    const pageSize = ref(10);
    // 分页改变
    const handleSizeChange = (val: number) => {
      console.log(`${val} items per page`);
    };
    // 分页未改变
    const handleCurrentChange = (val: number) => {
      console.log(`current page: ${val}`);
    };
    //全屏
    const full = ref(false);
    const toggleFullscreen = () => {
      if (full.value == false) {
        full.value = true;
      } else {
        full.value = false;
      }
    };
    return {
      dialogVisible,
      openDailog,
      ruleForm,
      tableData,
      handleSizeChange,
      handleCurrentChange,
      pageIndex,
      pageSize,
      radio1,
      radio,
      dynamicTags,
      handleClose,
      Delete,
      toggleFullscreen,
      FullScreen,
      full,
    };
  },
});
</script>
<style scoped>
.el-row {
  padding: 0 0 20px 0;
}
.el-form--inline .el-form-item{
  margin: 0;
}
</style>
